pub enum Event<T: Config> {
AttemptApproved {
lost: T::AccountId,
friend_group_index: FriendGroupIndex,
friend: T::AccountId,
},
AttemptCanceled {
lost: T::AccountId,
friend_group_index: FriendGroupIndex,
canceler: T::AccountId,
},
AttemptInitiated {
lost: T::AccountId,
friend_group_index: FriendGroupIndex,
initiator: T::AccountId,
},
AttemptFinished {
lost: T::AccountId,
friend_group_index: FriendGroupIndex,
inheritor: T::AccountId,
previous_inheritor: Option<T::AccountId>,
},
AttemptDiscarded {
lost: T::AccountId,
friend_group_index: FriendGroupIndex,
existing_inheritor: T::AccountId,
},
AttemptSlashed {
lost: T::AccountId,
friend_group_index: FriendGroupIndex,
},
FriendGroupsChanged {
lost: T::AccountId,
},
InheritorRevoked {
lost: T::AccountId,
},
RecoveredAccountControlled {
recovered: T::AccountId,
inheritor: T::AccountId,
call_hash: HashOf<T>,
call_result: DispatchResult,
},
// some variants omitted
}Expand description
The Event enum of this pallet
Variants
AttemptApproved
A recovery attempt was approved by a friend.
AttemptCanceled
A recovery attempt was canceled by either the lost account or the initiator.
AttemptInitiated
A recovery attempt was initiated by a friend.
AttemptFinished
A recovery attempt was finished.
AttemptDiscarded
A recovery attempt was discarded because the account was already recovered by a friend group of equal or higher priority.
The attempt is consumed (removed from storage) and its deposits are released, but the existing inheritor remains unchanged.
AttemptSlashed
A recovery attempt was slashed by the lost account.
The initiator will lose their security deposit.
FriendGroupsChanged
The friend groups of an account have been changed.
Fields
lost: T::AccountIdInheritorRevoked
The inheritor of a lost account was revoked by the lost account.
Fields
lost: T::AccountIdRecoveredAccountControlled
A recovered account was controlled by its inheritor.
Check the call_result to see if it was successful.