pub struct Pallet<T>(/* private fields */);Expand description
The Pallet struct, the main type that implements traits and standalone
functions within the pallet.
Implementations
Sourceimpl<T: Config> Pallet<T>
impl<T: Config> Pallet<T>
Sourcepub fn provided_block_number() -> ProvidedBlockNumberOf<T>
pub fn provided_block_number() -> ProvidedBlockNumberOf<T>
The provided block number that will be used to measure time.
Sourcepub fn friend_groups(lost: T::AccountId) -> Vec<FriendGroupOf<T>> ⓘ
pub fn friend_groups(lost: T::AccountId) -> Vec<FriendGroupOf<T>> ⓘ
The friend groups of an account that can initiate recovery attempts.
Sourcepub fn attempts(lost: T::AccountId) -> Vec<(FriendGroupOf<T>, AttemptOf<T>)>
pub fn attempts(lost: T::AccountId) -> Vec<(FriendGroupOf<T>, AttemptOf<T>)>
Ongoing recovery attempts for a lost account.
Sourcepub fn inheritor(lost: T::AccountId) -> Option<T::AccountId>
pub fn inheritor(lost: T::AccountId) -> Option<T::AccountId>
The account that inherited full access to the lost account.
Sourcepub fn inheritance(heir: T::AccountId) -> Vec<T::AccountId>
pub fn inheritance(heir: T::AccountId) -> Vec<T::AccountId>
All the recovered accounts that heir inherited access to.
Sourceimpl<T: Config> Pallet<T>
impl<T: Config> Pallet<T>
Sourcepub fn control_inherited_account(
origin: OriginFor<T>,
recovered: AccountIdLookupOf<T>,
call: Box<<T as Config>::RuntimeCall>,
) -> DispatchResult
pub fn control_inherited_account( origin: OriginFor<T>, recovered: AccountIdLookupOf<T>, call: Box<<T as Config>::RuntimeCall>, ) -> DispatchResult
Allows the inheritor of a recovered account to control it.
The controller is not allowed to dispatch calls of the recovery pallet. Otherwise they could mess with the recovery configuration and possibly cancel or slash attempts from higher-priority friend groups.
Sourcepub fn revoke_inheritor(origin: OriginFor<T>) -> DispatchResult
pub fn revoke_inheritor(origin: OriginFor<T>) -> DispatchResult
Revoke the inheritor of the calling (lost) account.
This removes the inheritor entry and refunds the inheritor deposit. Can only be called by the lost account itself after it regains access.
Sourcepub fn set_friend_groups(
origin: OriginFor<T>,
friend_groups: Vec<FriendGroupOf<T>>,
) -> DispatchResult
pub fn set_friend_groups( origin: OriginFor<T>, friend_groups: Vec<FriendGroupOf<T>>, ) -> DispatchResult
Set the friend groups of the calling account before it lost access.
Cannot be used while there are ongoing recovery attempts. The friends of each group MUST be sorted and unique. Trying to insert two friend groups with the same set of friends will result in an error.
A FriendGroupsChanged event is emitted only when the new friends groups differed from
the old ones.
Sourcepub fn initiate_attempt(
origin: OriginFor<T>,
lost: AccountIdLookupOf<T>,
friend_group_index: FriendGroupIndex,
) -> DispatchResult
pub fn initiate_attempt( origin: OriginFor<T>, lost: AccountIdLookupOf<T>, friend_group_index: FriendGroupIndex, ) -> DispatchResult
Attempt to recover a lost account by a friend within the given friend group.
The initiator’s approval is recorded automatically, so they do not need to call
approve_attempt themselves.
Once an account has been recovered by a friend group, no friend group of equal or lower
priority can open a new attempt: it will fail with Error::HigherPriorityRecovered.
Only a strictly higher-priority group (lower numerical
FriendGroup::inheritance_priority) can take over the inheritor.
Sourcepub fn approve_attempt(
origin: OriginFor<T>,
lost: AccountIdLookupOf<T>,
friend_group_index: FriendGroupIndex,
) -> DispatchResult
pub fn approve_attempt( origin: OriginFor<T>, lost: AccountIdLookupOf<T>, friend_group_index: FriendGroupIndex, ) -> DispatchResult
Approve the recovery for a lost account.
Must be called by a friend of the friend group that the recovery attempt belongs to that
did not yet vote. Voting is only allowed until the threshold is reached.
finish_attempt should be called after the last friend voted.
Sourcepub fn finish_attempt(
origin: OriginFor<T>,
lost: AccountIdLookupOf<T>,
friend_group_index: FriendGroupIndex,
) -> DispatchResult
pub fn finish_attempt( origin: OriginFor<T>, lost: AccountIdLookupOf<T>, friend_group_index: FriendGroupIndex, ) -> DispatchResult
Finish a recovery attempt and make the lost account accessible from the inheritor.
Can be called by anyone who is willing to pay for the inheritor deposit.
Sourcepub fn cancel_attempt(
origin: OriginFor<T>,
lost: AccountIdLookupOf<T>,
friend_group_index: FriendGroupIndex,
) -> DispatchResult
pub fn cancel_attempt( origin: OriginFor<T>, lost: AccountIdLookupOf<T>, friend_group_index: FriendGroupIndex, ) -> DispatchResult
The lost account can cancel an attempt at any moment; the initiator, only after a delay.
This will release the security deposit back to the initiator. The cancel delay must be respected if the initiator calls it to prevent it from front-running the lost account from slashing the attempt.
Sourcepub fn slash_attempt(
origin: OriginFor<T>,
friend_group_index: FriendGroupIndex,
) -> DispatchResult
pub fn slash_attempt( origin: OriginFor<T>, friend_group_index: FriendGroupIndex, ) -> DispatchResult
Slash a malicious recovery attempt and burn the security deposit of the initiator.
Sourceimpl<T: Config> Pallet<T>
impl<T: Config> Pallet<T>
pub fn friend_group_footprint(friend_groups: &FriendGroupsOf<T>) -> Footprint
pub fn attempt_footprint() -> Footprint
pub fn inheritor_footprint() -> Footprint
pub fn inheritor_ticket( who: &T::AccountId, ) -> Result<InheritorTicketOf<T>, DispatchError>
pub fn friend_group_of( lost: &T::AccountId, friend_group_index: FriendGroupIndex, ) -> Result<FriendGroupOf<T>, Error<T>>
pub fn attempt_of( lost: &T::AccountId, friend_group_index: FriendGroupIndex, ) -> Result<(AttemptOf<T>, AttemptTicketOf<T>, SecurityDepositOf<T>), Error<T>>
Sourcepub fn bound_friend_groups(
lost: &T::AccountId,
friend_groups: Vec<FriendGroupOf<T>>,
) -> Result<FriendGroupsOf<T>, Error<T>>
pub fn bound_friend_groups( lost: &T::AccountId, friend_groups: Vec<FriendGroupOf<T>>, ) -> Result<FriendGroupsOf<T>, Error<T>>
Sanity check the friend groups and bound them into a bounded vector.