referrerpolicy=no-referrer-when-downgrade

Inheritor

Type Alias Inheritor 

pub type Inheritor<T: Config> = StorageMap<_GeneratedPrefixForStorageInheritor<T>, Blake2_128Concat, T::AccountId, (InheritancePriority, T::AccountId, InheritorTicketOf<T>)>;
The account that inherited full access to a lost account after successful recovery.

The key is the lost account and the value is the inheritor account.

NOTE: This could be a multisig or proxy account

Storage type is [StorageMap] with key type T :: AccountId and value type (InheritancePriority, T :: AccountId, InheritorTicketOf < T >).

Aliased Type

pub struct Inheritor<T: Config>(/* private fields */);