pub type FriendGroups<T: Config> = StorageMap<_GeneratedPrefixForStorageFriendGroups<T>, Blake2_128Concat, T::AccountId, (FriendGroupsOf<T>, T::FriendGroupsConsideration)>;Expand description
The friend groups of an account that can conduct recovery attempts.
Modifying this storage is not possible while an account has ongoing recovery attempts.
Storage type is [StorageMap] with key type T :: AccountId and value type (FriendGroupsOf < T > , T :: FriendGroupsConsideration).
Aliased Type
pub struct FriendGroups<T: Config>(/* private fields */);